@@ -32,6 +32,8 @@ from .common import (
     get_block_mode,
 )
 from .exceptions import catch_exceptions
+
+from .geometry import check_validity
 from .stac import STACQuery
 
 
@@ -68,6 +70,9 @@ class DataBlock(ABC):
         """
         ensure_data_directories_exist()
         query: STACQuery = load_query()
+        # check for geometry validity
+        if query.bbox or query.intersects or query.contains:
+            check_validity(query_geom=query.geometry())
         dry_run: bool = get_block_mode() == BlockModes.DRY_RUN.value
         result: FeatureCollection = cls(**kwargs).fetch(query=query, dry_run=dry_run)
         save_metadata(result)
