@@ -25,7 +25,7 @@ logger = get_logger(__name__)
 
 def ensure_data_directories_exist():
     """Creates required directories for any block input and output (`/tmp/input`,
-     `tmp/output`, `/tmp/quicklooks`).
+    `tmp/output`, `/tmp/quicklooks`).
     """
     pathlib.Path("/tmp/input/").mkdir(parents=True, exist_ok=True)
     pathlib.Path("/tmp/output/").mkdir(parents=True, exist_ok=True)
@@ -94,8 +94,7 @@ class TestDirectoryContext(ContextDecorator):
         return self.test_dir
 
     def __exit__(self, *exc):
-        """Context exit point. Deletes temporary directory.
-        """
+        """Context exit point. Deletes temporary directory."""
         cleanup_test_directories(self.test_dir)
         return False
 
@@ -120,7 +119,7 @@ def load_query(validator: Callable = lambda x: True) -> STACQuery:
         A `STACQuery` object initialized with the parameters if valid.
     """
     data: str = os.environ.get("UP42_TASK_PARAMETERS", "{}")
-    logger.debug("Raw task parameters from UP42_TASK_PARAMETERS are: %s", data)
+    logger.debug(f"Raw task parameters from UP42_TASK_PARAMETERS are: {data}")
     query_data = json.loads(data)
     return STACQuery.from_dict(query_data, validator)
 
@@ -133,7 +132,7 @@ def load_params() -> dict:
         Dictionary of task parameters.
     """
     data: str = os.environ.get("UP42_TASK_PARAMETERS", "{}")
-    logger.debug("Fetching parameters for this block: %s", data)
+    logger.debug(f"Fetching parameters for this block: {data}")
     if data == "":
         data = "{}"
     return json.loads(data)
@@ -173,8 +172,9 @@ def save_metadata(result: FeatureCollection):
 def update_extents(feat_coll: FeatureCollection) -> FeatureCollection:
     """
     Updates all geometry extents to reflect actual images
-    Args:
-        feature_coll: geojson Feature Collection
+
+    Arguments:
+        feat_coll: geojson Feature Collection
 
     Returns: A FeatureCollection where image extents reflect actual images
     """
@@ -243,8 +243,8 @@ def encode_str_base64(string: str) -> str:
     special characters the process of getting them unharmed into a docker container sometimes fails. Encoding them
     in base64 is a save method to solve this problem.
 
-    Args:
-        A, potentially complex, non-encoded string
+    Arguments:
+        string: A, potentially complex, non-encoded string
     Returns:
         A base64-encoded string
     """
@@ -255,8 +255,8 @@ def decode_str_base64(string: str) -> str:
     """
     Inverter function for encode_str_base64
 
-    Args:
-        A base64-encoded string
+    Arguments:
+        string: A base64-encoded string
     Returns:
         A decoded string
     """
