@@ -15,7 +15,7 @@ def set_data_path(feature: Feature, data_path: Any) -> Feature:
     Parameters:
         feature: The output feature.
         data_path: Relative path to the output file from the main working folder
-        (i.e. `output.tif` is `/tmp/output/output.tif`).
+            (i.e. `output.tif` is `/tmp/output/output.tif`).
 
     Returns:
         Output feature with the data path set.
@@ -84,7 +84,9 @@ def get_output_filename_and_path(
 
 
 def get_in_out_feature_names_and_paths(
-    in_feature: Feature, postfix: Optional[str] = None, suffix: Optional[str] = None,
+    in_feature: Feature,
+    postfix: Optional[str] = None,
+    suffix: Optional[str] = None,
 ) -> Tuple[str, str, Path, Path]:
     """
     Utility to generate the input and output feature names and file paths. Will create
