@@ -2,21 +2,20 @@
 Utilities for handling geometry operations.
 """
 import copy
-from typing import List, Generator
 import math
+from typing import Generator, List
 
-import mercantile
 import geojson
+import mercantile
 import numpy as np
 import rasterio as rio
-import shapely
-import shapely.geometry
-from shapely.geometry import box
 from area import area
+from shapely.geometry import box, mapping, shape
+from shapely.validation import explain_validity
 
-from .stac import STACQuery, BoundingBox
-
+from .exceptions import SupportedErrors, UP42Error
 from .logging import get_logger
+from .stac import BoundingBox, STACQuery
 
 logger = get_logger(__name__)
 
@@ -35,9 +34,9 @@ def filter_tiles_intersect_with_geometry(
     Returns:
         Tile generator with only tiles that intersect geometry.
     """
-    geometry = shapely.geometry.shape(geometry)
+    geometry = shape(geometry)
     for tile in tiles:
-        tile_bbox = shapely.geometry.box(*mercantile.bounds(tile)._asdict().values())
+        tile_bbox = box(*mercantile.bounds(tile)._asdict().values())
         if geometry.intersects(tile_bbox) and not geometry.touches(tile_bbox):
             yield tile
 
@@ -55,11 +54,11 @@ def intersect_geojson_polygons(
     Returns:
         Geometry of the intersection.
     """
-    geometry1 = shapely.geometry.shape(geom1)
-    geometry2 = shapely.geometry.shape(geom2)
+    geometry1 = shape(geom1)
+    geometry2 = shape(geom2)
     intersection = geometry1.intersection(geometry2)
 
-    return shapely.geometry.mapping(intersection)
+    return mapping(intersection)
 
 
 def get_query_bbox(query: STACQuery) -> BoundingBox:
@@ -239,3 +238,22 @@ def meta_is_equal(meta1: dict, meta2: dict, rtol=1e-05, atol=1e-08) -> bool:
     del meta2["transform"]
 
     return isclose(meta1_transform, meta2_transform, rtol, atol) and meta1 == meta2
+
+
+def check_validity(query_geom: dict):
+    """checks for validity of the input geometry supplied by user
+
+    Args:
+        query_geom (dict): geojson like dict
+
+    Raises:
+        UP42Error: raises up42 INPUT_PARAMETERS_ERROR with validity explanation
+    """
+    shapely_geom = shape(query_geom)
+
+    if not shapely_geom.is_valid:
+        explanation = explain_validity(shapely_geom)
+        raise UP42Error(
+            SupportedErrors.INPUT_PARAMETERS_ERROR,
+            f"Input geometry is not valid due to following reason: {explanation}",
+        )
